aboutsummaryrefslogtreecommitdiff
path: root/backends/fs
diff options
context:
space:
mode:
authorMax Horn2008-02-23 19:01:12 +0000
committerMax Horn2008-02-23 19:01:12 +0000
commit80d55b0388ef5883202fa13035115d79046b3072 (patch)
treec669cb6eaeb6bc69217df084525f77ee2745f72f /backends/fs
parent1cf9fc944a8488e928da49208118a32ea10c3c62 (diff)
downloadscummvm-rg350-80d55b0388ef5883202fa13035115d79046b3072.tar.gz
scummvm-rg350-80d55b0388ef5883202fa13035115d79046b3072.tar.bz2
scummvm-rg350-80d55b0388ef5883202fa13035115d79046b3072.zip
Renamed AbstractFilesystemFactory to FilesystemFactory
svn-id: r30935
Diffstat (limited to 'backends/fs')
-rw-r--r--backends/fs/amigaos4/amigaos4-fs-factory.h6
-rw-r--r--backends/fs/dc/ronincd-fs-factory.h6
-rw-r--r--backends/fs/ds/ds-fs-factory.h6
-rw-r--r--backends/fs/fs-factory.cpp (renamed from backends/fs/abstract-fs-factory.cpp)6
-rw-r--r--backends/fs/fs-factory.h (renamed from backends/fs/abstract-fs-factory.h)18
-rw-r--r--backends/fs/gp32/gp32-fs-factory.h6
-rw-r--r--backends/fs/morphos/abox-fs-factory.h6
-rw-r--r--backends/fs/palmos/palmos-fs-factory.h6
-rw-r--r--backends/fs/posix/posix-fs-factory.h6
-rw-r--r--backends/fs/ps2/ps2-fs-factory.h6
-rw-r--r--backends/fs/psp/psp-fs-factory.h6
-rw-r--r--backends/fs/symbian/symbian-fs-factory.h6
-rw-r--r--backends/fs/windows/windows-fs-factory.h6
13 files changed, 44 insertions, 46 deletions
diff --git a/backends/fs/amigaos4/amigaos4-fs-factory.h b/backends/fs/amigaos4/amigaos4-fs-factory.h
index 262b3ed233..58a7dcd372 100644
--- a/backends/fs/amigaos4/amigaos4-fs-factory.h
+++ b/backends/fs/amigaos4/amigaos4-fs-factory.h
@@ -26,14 +26,14 @@
#define AMIGAOS_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates AmigaOSFilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class AmigaOSFilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<AmigaOSFilesystemFactory> {
+class AmigaOSFilesystemFactory : public FilesystemFactory, public Common::Singleton<AmigaOSFilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates AmigaOSFilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/
diff --git a/backends/fs/dc/ronincd-fs-factory.h b/backends/fs/dc/ronincd-fs-factory.h
index e49c2c04fa..532a6d3333 100644
--- a/backends/fs/dc/ronincd-fs-factory.h
+++ b/backends/fs/dc/ronincd-fs-factory.h
@@ -26,14 +26,14 @@
#define RONINCD_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates RoninCDFilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class RoninCDFilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<RoninCDFilesystemFactory> {
+class RoninCDFilesystemFactory : public FilesystemFactory, public Common::Singleton<RoninCDFilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates RoninCDFilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/
diff --git a/backends/fs/ds/ds-fs-factory.h b/backends/fs/ds/ds-fs-factory.h
index 292a2baa69..bff21a309d 100644
--- a/backends/fs/ds/ds-fs-factory.h
+++ b/backends/fs/ds/ds-fs-factory.h
@@ -26,14 +26,14 @@
#define DS_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates DSFilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class DSFilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<DSFilesystemFactory> {
+class DSFilesystemFactory : public FilesystemFactory, public Common::Singleton<DSFilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates DSFilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/
diff --git a/backends/fs/abstract-fs-factory.cpp b/backends/fs/fs-factory.cpp
index 8cf936f5bc..035e4bf2f8 100644
--- a/backends/fs/abstract-fs-factory.cpp
+++ b/backends/fs/fs-factory.cpp
@@ -22,7 +22,7 @@
* $Id$
*/
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/*
* All the following includes choose, at compile time, which specific backend will be used
@@ -58,9 +58,9 @@
/**
* Creates concrete FilesystemFactory objects depending on the current architecture.
*
* @return AbstractFilesystemFactory* The specific factory for the current architecture.
*/
-AbstractFilesystemFactory *AbstractFilesystemFactory::makeFSFactory() {
+FilesystemFactory *FilesystemFactory::makeFSFactory() {
#if defined(__amigaos4__)
return &AmigaOSFilesystemFactory::instance();
#elif defined(__DC__)
@@ -58,9 +58,9 @@
* Creates concrete FilesystemFactory objects depending on the current architecture.
*
- * @return AbstractFilesystemFactory* The specific factory for the current architecture.
+ * @return FilesystemFactory* The specific factory for the current architecture.
*/
diff --git a/backends/fs/abstract-fs-factory.h b/backends/fs/fs-factory.h
index c4ce277505..bd208a7beb 100644
--- a/backends/fs/abstract-fs-factory.h
+++ b/backends/fs/fs-factory.h
@@ -22,8 +22,8 @@
* $Id$
*/
-#ifndef ABSTRACT_FILESYSTEM_FACTORY_H
-#define ABSTRACT_FILESYSTEM_FACTORY_H
+#ifndef FILESYSTEM_FACTORY_H
+#define FILESYSTEM_FACTORY_H
#include "common/str.h"
#include "backends/fs/abstract-fs.h"
@@ -31,14 +31,12 @@
/**
* Creates concrete FilesystemNode objects depending on the current architecture.
*/
-class AbstractFilesystemFactory {
+class FilesystemFactory {
public:
- typedef Common::String String;
-
/**
* Destructor.
*/
- virtual ~AbstractFilesystemFactory() {}
+ virtual ~FilesystemFactory() {}
/**
* Returns a node representing the "current directory".
@@ -58,7 +56,7 @@ public:
*
* @param path The path string to create a FilesystemNode for.
*/
- virtual AbstractFilesystemNode *makeFileNodePath(const String &path) const = 0;
+ virtual AbstractFilesystemNode *makeFileNodePath(const Common::String &path) const = 0;
/**
* Returns a special node representing the filesystem root.
@@ -71,10 +69,10 @@ public:
/**
* Meta-factory method which returns a concrete AbstractFilesystemFactory
* instance depending on the current architecture.
*/
- static AbstractFilesystemFactory *makeFSFactory();
+ static FilesystemFactory *makeFSFactory();
};
-#endif /*ABSTRACT_FILESYSTEM_FACTORY_H*/
+#endif /*FILESYSTEM_FACTORY_H*/
@@ -71,10 +69,10 @@ public:
/**
- * Meta-factory method which returns a concrete AbstractFilesystemFactory
+ * Meta-factory method which returns a concrete FilesystemFactory
* instance depending on the current architecture.
*/
diff --git a/backends/fs/gp32/gp32-fs-factory.h b/backends/fs/gp32/gp32-fs-factory.h
index 90c6bd9500..7e6cb595ca 100644
--- a/backends/fs/gp32/gp32-fs-factory.h
+++ b/backends/fs/gp32/gp32-fs-factory.h
@@ -26,14 +26,14 @@
#define GP32_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates GP32FilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class GP32FilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<GP32FilesystemFactory> {
+class GP32FilesystemFactory : public FilesystemFactory, public Common::Singleton<GP32FilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates GP32FilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/
diff --git a/backends/fs/morphos/abox-fs-factory.h b/backends/fs/morphos/abox-fs-factory.h
index 1adbd1475a..0a53822447 100644
--- a/backends/fs/morphos/abox-fs-factory.h
+++ b/backends/fs/morphos/abox-fs-factory.h
@@ -26,14 +26,14 @@
#define ABOX_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates ABoxFilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class ABoxFilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<ABoxFilesystemFactory> {
+class ABoxFilesystemFactory : public FilesystemFactory, public Common::Singleton<ABoxFilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates ABoxFilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/
diff --git a/backends/fs/palmos/palmos-fs-factory.h b/backends/fs/palmos/palmos-fs-factory.h
index 9d873eeb12..3ea8b5fe47 100644
--- a/backends/fs/palmos/palmos-fs-factory.h
+++ b/backends/fs/palmos/palmos-fs-factory.h
@@ -26,14 +26,14 @@
#define PALMOS_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates PalmOSFilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class PalmOSFilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<PalmOSFilesystemFactory> {
+class PalmOSFilesystemFactory : public FilesystemFactory, public Common::Singleton<PalmOSFilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates PalmOSFilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/
diff --git a/backends/fs/posix/posix-fs-factory.h b/backends/fs/posix/posix-fs-factory.h
index cf1204c0a3..d8eecda6ef 100644
--- a/backends/fs/posix/posix-fs-factory.h
+++ b/backends/fs/posix/posix-fs-factory.h
@@ -26,14 +26,14 @@
#define POSIX_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates POSIXFilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class POSIXFilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<POSIXFilesystemFactory> {
+class POSIXFilesystemFactory : public FilesystemFactory, public Common::Singleton<POSIXFilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates POSIXFilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/
diff --git a/backends/fs/ps2/ps2-fs-factory.h b/backends/fs/ps2/ps2-fs-factory.h
index a7a52fdca3..1b74ae25d1 100644
--- a/backends/fs/ps2/ps2-fs-factory.h
+++ b/backends/fs/ps2/ps2-fs-factory.h
@@ -26,14 +26,14 @@
#define PS2_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates PS2FilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class Ps2FilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<Ps2FilesystemFactory> {
+class Ps2FilesystemFactory : public FilesystemFactory, public Common::Singleton<Ps2FilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates PS2FilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/
diff --git a/backends/fs/psp/psp-fs-factory.h b/backends/fs/psp/psp-fs-factory.h
index 143b2ce684..ffa934755f 100644
--- a/backends/fs/psp/psp-fs-factory.h
+++ b/backends/fs/psp/psp-fs-factory.h
@@ -26,14 +26,14 @@
#define PSP_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates PSPFilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class PSPFilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<PSPFilesystemFactory> {
+class PSPFilesystemFactory : public FilesystemFactory, public Common::Singleton<PSPFilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates PSPFilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/
diff --git a/backends/fs/symbian/symbian-fs-factory.h b/backends/fs/symbian/symbian-fs-factory.h
index 4b663fd6b9..502fba2930 100644
--- a/backends/fs/symbian/symbian-fs-factory.h
+++ b/backends/fs/symbian/symbian-fs-factory.h
@@ -26,14 +26,14 @@
#define SYMBIAN_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates SymbianFilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class SymbianFilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<SymbianFilesystemFactory> {
+class SymbianFilesystemFactory : public FilesystemFactory, public Common::Singleton<SymbianFilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates SymbianFilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/
diff --git a/backends/fs/windows/windows-fs-factory.h b/backends/fs/windows/windows-fs-factory.h
index 5989cbb17d..0745b286a8 100644
--- a/backends/fs/windows/windows-fs-factory.h
+++ b/backends/fs/windows/windows-fs-factory.h
@@ -26,14 +26,14 @@
#define WINDOWS_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates WindowsFilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class WindowsFilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<WindowsFilesystemFactory> {
+class WindowsFilesystemFactory : public FilesystemFactory, public Common::Singleton<WindowsFilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates WindowsFilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/